@@ -24,9 +24,6 @@ def init(timbermill_hostname: str, env: str = None, static_event_params=None, lo
 
 
 def start_task(name: str, retention_days: int = None):
-    if not __is_initiated():
-        return TimberLogNotInitiatedContext()
-
     return TimberLogContext(name, retention_days)
 
 
@@ -65,9 +62,6 @@ class TimberLogContext:
 
 
 def start(name: str, parent_id: str = None, retention_days: int = None) -> str:
-    if not __is_initiated():
-        return None
-
     event, task_id, parent_id = __handle_new_task(name, consts.EVENT_TYPE_START, parent_id=parent_id, retention_days=retention_days)
     stack = __get_stack()
     stack.push((task_id, parent_id))
@@ -76,16 +70,11 @@ def start(name: str, parent_id: str = None, retention_days: int = None) -> str:
 
 
 def success():
-    if not __is_initiated():
-        return
-
     event = __create_end_event(consts.EVENT_TYPE_END_SUCCESS)
     timberlog_event_handler.submit_event(event)
 
 
 def end_with_error(exception: BaseException = None):
-    if not __is_initiated():
-        return
     if exception is None:
         exception = traceback.format_exc()
 
@@ -95,9 +84,6 @@ def end_with_error(exception: BaseException = None):
 
 
 def spot(name: str, context: dict = None, strings: dict = None, metrics: dict = None, text: dict = None, parent_id: str = None, task_success: bool = True) -> str:
-    if not __is_initiated():
-        return None
-
     if task_success:
         status = consts.SUCCESS_STATUS
     else:
@@ -124,9 +110,6 @@ def add_metrics(**kwargs):
 
 
 def info(context: dict = None, strings: dict = None, metrics: dict = None, text: dict = None):
-    if not __is_initiated():
-        return None
-
     stack = __get_stack()
 
     if stack.is_empty():
@@ -207,16 +190,6 @@ def __generate_task_id(name: str) -> str:
     return name + '_' + str(int(round(time.time() * 1000))) + '_' + str(randint(0, 10000000))
 
 
-def __is_initiated():
-    global initiated
-
-    if not initiated:
-        logging.getLogger(__name__).error('Trying to create a new timbermill spot event without it being initiated, ignoring..')
-        return False
-    else:
-        return True
-
-
 def get_current_task_id() -> str:
     stack = __get_stack()
     curr_task_tuple = stack.peek()
